@@ -6,11 +6,13 @@ from scipy.fft import fftn
 from numpy.linalg import norm
 from numpy import (
     ndarray, concatenate, argmax, array,
-    zeros, mean, max, min, sum, pad
+    zeros, mean, sum, pad
 )
+import numpy
 
 from ffast.poincare.token import Token
 from ffast.poincare.utils import Poincare, METAPHONES, SIZE_METAPHONES
+from ffast.wordnet.utils import STOPWORDS
 
 class Tokens:
     def __init__(self, tokens:List[Token], pad_token_id:int) -> None:
@@ -51,7 +53,7 @@ class Tokens:
         return list(map(self.__weight,self.tokens))
 
     def skip_common_words(self) -> "Tokens":
-        return Tokens(list(filter(lambda token:self.__weight(token)==0),self.tokens),pad_token_id=self.pad_token_id)
+        return Tokens(list(filter(lambda token:self.__weight(token)>0.,self.tokens)),pad_token_id=self.pad_token_id)
 
     def skip_unknowns(self) -> "Tokens":
         return Tokens(list(filter(lambda token:token.morphology != Poincare.UNKNOWN.value,self.tokens)),pad_token_id=self.pad_token_id)
@@ -75,8 +77,8 @@ class Tokens:
     def __power_means(vectors:List[ndarray]) -> ndarray:
         positive_vectors = list(map(abs,vectors))
         return concatenate([
-            max(vectors,axis=0),
-            min(vectors,axis=0),
+            numpy.max(vectors,axis=0),
+            numpy.min(vectors,axis=0),
             mean(vectors,axis=0),
             gmean(positive_vectors),
             hmean(positive_vectors),
@@ -117,6 +119,8 @@ class Tokens:
     
     @staticmethod
     def __weight(token:Token,minimum_weight:float = 0.,maximum_weight:float = 1.,scaling_factor:float = 10.) -> float:
+        if token.text in STOPWORDS:
+            return 0.
         approximation_of_token_frequency = .5 - norm(token.semantics)
         approximation_of_token_frequency *= scaling_factor
         return min(maximum_weight,max(minimum_weight,approximation_of_token_frequency))
\ No newline at end of file
