@@ -1,9 +1,12 @@
 from typing import Generator, Tuple
 from enum import Enum 
+from pathlib import Path 
 
-from nltk.corpus import stopwords
+import nltk
+nltk.data.path.append(f"{Path(__file__).parent}/corpora")
+
+from nltk.corpus import stopwords, wordnet
 from nltk.corpus.reader.wordnet import Synset
-from nltk.corpus import wordnet
 from nltk.corpus.reader.wordnet import ADJ, ADJ_SAT, ADV, NOUN, VERB
 
 from ffast.preprocessor import PreprocessingPipeline
